/*
       fnet.h
       GNU Licence

       author: Rafal Michniewicz 
        email: <rafim@data.pl>
       jabber: rafim@jabber.org
    home page: http://smbc.airm.net

  last update: 2004-08-08
*/
// -------------------------------------------------------------------
#include <curses.h>

int readline(register int fd, register char *ptr, register int maxlen);
int writen(register int fd, register char *ptr, register int nbytes);
void str_echo(int sockfd);
int readlineii( int sockfd, char *buf, int size, int *linepos );
int readlineie(WINDOW *win, char *buf, int size, int *linepos );
void refreshw(WINDOW *win, char *buf);
void reverse(char *str);
void itoa(char *str, int strLen, int n);
void refreshTxtInWin(WINDOW *win, int y, int x, char *buf, int winSize, int startidx, int colorPair, int attr, int xDelta);
int readlineWait(WINDOW *win, int wy, int wx, char *buf, int sizebuf, int winSize, int colorPair);
int ssqr(int Rv, int Rpot);
int strhextoi(char *str);
void RmvwprintwCenter(WINDOW *win, int i, char *str);
int readlineOneCharNoDelay(WINDOW *win, int wy, int wx, char *buf, int sizebuf, int winSize, int colorPair, int *ctrlp, int Rnodelay, int *startidx, int *wxx, int *first);
int readlineWaitForOneChar(WINDOW *win, int wy, int wx, char *buf, int sizebuf, int winSize, int colorPair, int *ctrlp, int *startidx, int *wxx);
void RstrToUpper(char *str);
void RstrToUpperCopy(char *Dstr, char *Sstr);
void RgetFileFromTwoDirs(char **RfileName, char *RdirBig, char *RdirSmall);
void *Rmalloc(size_t size);
